.. _papers:

Citation & References
=====================

Cite SCALib
-----------

If you use SCALib in your research, please cite our `software paper <https://doi.org/10.21105/joss.05196>`_:

.. code-block::

    Cassiers et al., (2023). SCALib: A Side-Channel Analysis Library. Journal of Open Source Software, 8(86), 5196, https://doi.org/10.21105/joss.05196

Bibtex:

.. code-block::

   @article{scalib,
       doi = {10.21105/joss.05196},
       url = {https://doi.org/10.21105/joss.05196},
       year = {2023},
       publisher = {The Open Journal},
       volume = {8},
       number = {86},
       pages = {5196},
       author = {Gaëtan Cassiers and Olivier Bronchain},
       title = {SCALib: A Side-Channel Analysis Library}, journal = {Journal of Open Source Software}
   }


Publications using SCALib
-------------------------

*This list is incomplete!*
Help us keeping it up-to-date: add your publications by
`editing this file <https://github.com/simple-crypto/SCALib/edit/main/docs/source/papers.rst>`_.


1. "Mode-Level vs. Implementation-Level Physical Security in Symmetric
   Cryptography: A Practical Guide Through the Leakage-Resistance Jungle", D.
   Bellizia, O. Bronchain, G. Cassiers, V. Grosso, Chun Guo, C. Momin, O.
   Pereira, T. Peters, F.-X. Standaert at CRYPTO2020.
2. "Exploring Crypto-Physical Dark Matter and Learning with Physical Rounding
   Towards Secure and Efficient Fresh Re-Keying", S. Duval, P. Méaux, C. Momin,
   F.-X. Standaert in TCHES2021 - Issue 1.
3. "Breaking Masked Implementations with Many Shares on 32-bit Software
   Platforms or When the Security Order Does Not Matter". O. Bronchain, F.-X.
   Standaert in TCHES2021 - Issue 3.
4. "Improved Leakage-Resistant Authenticated Encryption based on Hardware AES
   Coprocessors". O. Bronchain, C. Momin, T. Peters, F.-X. Standaert in
   TCHES2021 - Issue 3.
5. "Riding the Waves Towards Generic Single-Cycle Masking in Hardware". R.
   Nagpal, B. Girgel, R. Primas, S. Mangard, eprint 2022/505.
6. "Bitslice Masking and Improved Shuffling: How and When to Mix Them in
   Software?". M. Azouaoui, O. Bronchain, V. Grosso, K.  Papagiannopoulos,
   F.-X.  Standaert, TCHES2022 - Issue 2.
7. "A Second Look at the ASCAD Databases", M. Egger, T. Schamberger, L.
   Tebelmann, F. Lippert, G. Sigl, COSADE 2022. 
8. "Give Me 5 Minutes: Attacking ASCAD with a Single Side-Channel Trace". O.
   Bronchain, G. Cassiers, F.-X. Standaert, eprint 2021/817. 
9. "Towards a Better Understanding of Side-Channel Analysis Measurements
   Setups". D. Bellizia, B. Udvarhelyi, F.-X. Standaert, CARDIS 2021. 
10. "A Finer-Grain Analysis of the Leakage (Non) Resilience of OCB". F. Berti,
    S. Bhasin, J. Breier, X. Hou, R. Poussier, F.-X. Standaert, B. Udvarhelyi
    in TCHES2022 - Issue 1. 
11. "Bitslicing Arithmetic/Boolean Masking Conversions for Fun and Profit: with
    Application to Lattice-Based KEMs.", O. Bronchain, G. Cassiers, TCHES 2022.
12. "Low-Latency Masking with Arbitrary Protection Order Based on Click
    Elements", M. Simões, L. Bossuet, N. Bruneau, V. Grosso, P. Haddad, T.
    Sarno, HOST 2023.
13. "Removing the Field Size Loss from Duc et al.’s Conjectured Bound for
    Masked Encodings.", Béguinot, J. et al., COSADE 2023.
14. "Self-timed Masking: Implementing Masked S-Boxes Without Registers."
    Simões, M., Bossuet, L., Bruneau, N., Grosso, V., Haddad, P., Sarno, T.,
    CARDIS 2022
15. "Prime-Field Masking in Hardware and its Soundness against Low-Noise SCA
    Attacks", Cassiers, G., Masure, L., Momin, C., Moos, T., Standaert, F.-X.,
    TCHES 2023.
16. "Effective and Efficient Masking with Low Noise Using Small-Mersenne-Prime
    Ciphers.", Masure, L., Méaux, P., Moos, T., Standaert, F. X., EUROCRYPT
    2023.
